###################################################
### chunk number 1: options
###################################################

options(width=80);



###################################################
### chunk number 2: libraries
###################################################

library(affy)
library(geneplotter)



###################################################
### chunk number 3: getRMAFromXLS
###################################################

rda <- "ovcaRMAFromXLS";
rdaFile <- paste("RDataObjects", paste(rda, "Rda", sep="."), 
                 sep=.Platform$file.sep);
if(file.exists(rdaFile)){
  cat(paste("loading", rda, "from cache\n"))
  load(rdaFile);
}else{
  ovcaRMAFromXLS <- 
    read.table(file.path("DukeWebSite", "correctedPlatinum_RMA.csv"),
               header=TRUE, sep=",", row.names=1, check.names=FALSE);
  ovcaRMAFromXLS <- as.matrix(ovcaRMAFromXLS);
  save(ovcaRMAFromXLS, file=rdaFile);
} 



###################################################
### chunk number 4: checkRMAFromXLSNums
###################################################

dim(ovcaRMAFromXLS);
ovcaRMAFromXLS[1:3,1:5];



###################################################
### chunk number 5: getShortNames1
###################################################

celFiles <- dir(file.path("DukeWebSite", "PlatinumJCO"));
length(celFiles)
celFiles[1:3]



###################################################
### chunk number 6: getShortNames2
###################################################

temp1 <- unlist(strsplit(celFiles, ".cel"))
temp1[1:3]
temp2 <- unlist(lapply(strsplit(temp1,"h133a_"),function(x){x[2]}))
temp2[1:3]
celShortNames <- temp2;
rm("temp1", "temp2");
names(celShortNames) <- celFiles;
names(celFiles) <- celShortNames;

celFiles[1:3]
celShortNames[1:3]



###################################################
### chunk number 7: tryMatchingNames
###################################################

sum(!is.na(match(celShortNames, colnames(ovcaRMAFromXLS))))
celShortNames[is.na(match(celShortNames, colnames(ovcaRMAFromXLS)))]
colnames(ovcaRMAFromXLS)[is.na(match(colnames(ovcaRMAFromXLS),
                                     celShortNames))]



###################################################
### chunk number 8: adjustNames
###################################################

celShortNames["0074_1827_h133a_.08.cel"] <- "0.08";
celShortNames["0074_2484_h133a_3250.cel"] <- "3249";
sum(!is.na(match(celShortNames, colnames(ovcaRMAFromXLS))))

names(celFiles)[celFiles == "0074_1827_h133a_.08.cel"] <- "0.08";
names(celFiles)[celFiles == "0074_2484_h133a_3250.cel"] <- "3249";
sum(!is.na(match(names(celFiles), colnames(ovcaRMAFromXLS))))



###################################################
### chunk number 9: getRMAFromCEL
###################################################

rda <- "ovcaRMAFromCELEset";
rdaFile <- paste("RDataObjects", paste(rda, "Rda", sep="."), 
                 sep=.Platform$file.sep);
if(file.exists(rdaFile)){
  cat(paste("loading", rda, "from cache\n"))
  load(rdaFile);
}else{
  ovcaRMAFromCELEset <- 
    justRMA(celfile.path=file.path("DukeWebSite", "PlatinumJCO"));
  save(ovcaRMAFromCELEset, file=rdaFile);
} 



###################################################
### chunk number 10: getExprs
###################################################

ovcaRMAFromCEL <- exprs(ovcaRMAFromCELEset);
ovcaRMAFromCEL[1:3,1:3]
colnames(ovcaRMAFromCEL) <- celShortNames[colnames(ovcaRMAFromCEL)];
ovcaRMAFromCEL[1:3,1:3]



###################################################
### chunk number 11: omittedProbesets
###################################################

omittedProbesets <- setdiff(rownames(ovcaRMAFromCEL),
                            rownames(ovcaRMAFromXLS));
length(omittedProbesets);
affyControls <- grep("^AFFX", omittedProbesets);
length(affyControls);
omittedProbesets[-affyControls];



###################################################
### chunk number 12: checkAgreementForCol1
###################################################

smoothScatter(ovcaRMAFromCEL[rownames(ovcaRMAFromXLS),"872"],
     ovcaRMAFromXLS[,"872"],
     xlab="CEL: Sample 872",
     ylab="XLS: Sample 872",
     main="Two RMA Quantifications of Sample 872")



###################################################
### chunk number 13: checkCorrWithCol1
###################################################

corWith872 <- cor(ovcaRMAFromCEL[rownames(ovcaRMAFromXLS),"872"],
                  ovcaRMAFromXLS)
plot(t(corWith872), 
     xlab="Column in ovcaRMAFromXLS",
     ylab="Correlation with Sample 872 from CEL",
     main="Correlations of 872 from CEL with All Columns of XLS")

colnames(corWith872)[which.max(corWith872)];



###################################################
### chunk number 14: bestFitFor872
###################################################

smoothScatter(ovcaRMAFromCEL[rownames(ovcaRMAFromXLS),"872"],
     ovcaRMAFromXLS[,"2476"],
     xlab="CEL: Sample 872",
     ylab="XLS: Sample 2476",
     main="Two RMA Quantifications: 872 From CEL, 2476 From XLS")



###################################################
### chunk number 15: checkAgreementForCol2
###################################################

smoothScatter(ovcaRMAFromCEL[rownames(ovcaRMAFromXLS),"922"],
     ovcaRMAFromXLS[,"922"],
     xlab="CEL: Sample 922",
     ylab="XLS: Sample 922",
     main="Two RMA Quantifications of Sample 922")



###################################################
### chunk number 16: checkCorWithCol2
###################################################

corWith922 <- cor(ovcaRMAFromCEL[rownames(ovcaRMAFromXLS),"922"],
                  ovcaRMAFromXLS)
plot(t(corWith922), 
     xlab="Column in ovcaRMAFromXLS",
     ylab="Correlation with Sample 922 from CEL",
     main="Correlations of 922 from CEL with All Columns of XLS")

colnames(corWith922)[which.max(corWith922)];



###################################################
### chunk number 17: bestFitFor922
###################################################

smoothScatter(ovcaRMAFromCEL[rownames(ovcaRMAFromXLS),"922"],
     ovcaRMAFromXLS[,"2895"],
     xlab="CEL: Sample 922",
     ylab="XLS: Sample 2895",
     main="Two RMA Quantifications: 922 From CEL, 2895 From XLS")



###################################################
### chunk number 18: buildCorMatrix
###################################################

corCELWithXLS <- cor(ovcaRMAFromCEL[rownames(ovcaRMAFromXLS),],
                     ovcaRMAFromXLS[,colnames(ovcaRMAFromCEL)])
image(1:119, 1:119, corCELWithXLS < 0.98,
      xlab="CEL", ylab="XLS", 
      main="Corr > 0.98, Names in ovcaRMAFromCEL Order")



###################################################
### chunk number 19: buildGuessMap
###################################################

bestXLSFitsToGivenCEL <- max.col(corCELWithXLS);
bestCELFitsToGivenXLS <- max.col(t(corCELWithXLS));

plot(bestCELFitsToGivenXLS, 1:119, cex=2, lwd=2,
     xlab="CEL", ylab="XLS", 
     main="Row and Col Maximum Correlations")
points(1:119, bestXLSFitsToGivenCEL, pch=3, cex=2, col="red") 



###################################################
### chunk number 20: findOddCELs
###################################################

which(duplicated(bestXLSFitsToGivenCEL))
bestXLSFitsToGivenCEL[c(62,108,119)]
which(bestXLSFitsToGivenCEL == 5)
bestCELFitsToGivenXLS[5]
rownames(corCELWithXLS)[c(62,108,119)]



###################################################
### chunk number 21: findOddXLS
###################################################

which(duplicated(bestCELFitsToGivenXLS))
bestCELFitsToGivenXLS[c(96,112,113)]
which(bestCELFitsToGivenXLS == 110)
bestXLSFitsToGivenCEL[110]
which(bestCELFitsToGivenXLS == 109)
bestXLSFitsToGivenCEL[109]
which(bestCELFitsToGivenXLS == 112)
bestXLSFitsToGivenCEL[112]
colnames(corCELWithXLS)[c(56,112,113)]



###################################################
### chunk number 22: quantifyBildCELFiles
###################################################

rda <- "ovcaRMAFromBildEset";
rdaFile <- paste("RDataObjects", paste(rda, "Rda", sep="."), 
                 sep=.Platform$file.sep);
if(file.exists(rdaFile)){
  cat(paste("loading", rda, "from cache\n"))
  load(rdaFile);
}else{
  ovcaRMAFromBildEset <- 
    justRMA(celfile.path=file.path("OtherData", "BildNature06", 
              "OvarianTumorData"));
  save(ovcaRMAFromBildEset, file=rdaFile);
} 

ovcaRMAFromBild <- exprs(ovcaRMAFromBildEset);



###################################################
### chunk number 23: buildBildCheck
###################################################

corBildWithXLS <- 
  cor(ovcaRMAFromBild[rownames(ovcaRMAFromXLS),],
      ovcaRMAFromXLS)

bildCheck <- 
  cbind(xlsName=colnames(corCELWithXLS), 
        celName=colnames(corCELWithXLS), 
        bildName=colnames(corCELWithXLS), 
        bildCor1=rep(0,119),
        bildCor2=rep(0,119), 
        bildCor3=rep(0,119))
for(i1 in 1:length(colnames(corCELWithXLS))){
  bildCheck[i1,"celName"] <- 
    rownames(corCELWithXLS)[which.max(corCELWithXLS[,i1])]
  bildCheck[i1,"bildName"] <- 
    rownames(corBildWithXLS)[which.max(corBildWithXLS[,colnames(corCELWithXLS)[i1]])]
  bildCheck[i1,4:6] <- 
    sort(corBildWithXLS[,colnames(corCELWithXLS)[i1]])[c(146,145,144)]    
}
bildCheck <- as.data.frame(bildCheck)
bildCheck["xlsName"] <- as.character(bildCheck[,"xlsName"])
bildCheck["celName"] <- as.character(bildCheck[,"celName"])
bildCheck["bildName"] <- as.character(bildCheck[,"bildName"])
bildCheck[,"bildCor1"] <- 
  as.numeric(as.character(bildCheck[,"bildCor1"]))
bildCheck[,"bildCor2"] <- 
  as.numeric(as.character(bildCheck[,"bildCor2"]))
bildCheck[,"bildCor3"] <- 
  as.numeric(as.character(bildCheck[,"bildCor3"]))

bildCheck <- bildCheck[order(bildCheck[,"bildName"]),]
rownames(bildCheck) <- 1:119



###################################################
### chunk number 24: showBildCheck
###################################################

bildCheck;



###################################################
### chunk number 25: plotBestBildFits
###################################################

plot(bildCheck[order(bildCheck[,4]),4],ylim=c(0.93,1),
     xlab="Index", ylab="Correlation, XLS w Best 3 CELs",
     main="Correlation of XLS Files with 3 Best CELs, Sorted by Max Corr")
points(bildCheck[order(bildCheck[,4]),5],ylim=c(0.93,1),col="red",pch="+")
points(bildCheck[order(bildCheck[,4]),6],ylim=c(0.93,1),col="blue",pch="x")



###################################################
### chunk number 26: saveStuff
###################################################

save(celFiles, file=paste("RDataObjects", "celFiles.Rda",
                     sep=.Platform$file.sep))
save(celShortNames, file=paste("RDataObjects", "celShortNames.Rda",
                          sep=.Platform$file.sep))
save(ovcaRMAFromCEL, file=paste("RDataObjects", "ovcaRMAFromCEL.Rda",
                          sep=.Platform$file.sep))
save(corCELWithXLS, file=paste("RDataObjects", "corCELWithXLS.Rda",
                          sep=.Platform$file.sep))
save(ovcaRMAFromBild, file=paste("RDataObjects", "ovcaRMAFromBild.Rda",
                          sep=.Platform$file.sep))
save(corBildWithXLS, file=paste("RDataObjects", "corBildWithXLS.Rda",
                             sep=.Platform$file.sep))
save(bildCheck, file=paste("RDataObjects", "bildCheck.Rda",
                             sep=.Platform$file.sep))



###################################################
### chunk number 27: sessionInfo
###################################################

sessionInfo();



