###################################################
### chunk number 1: options
###################################################

options(width=80);



###################################################
### chunk number 2: getClinicalDressman
###################################################

clinicalDressman <- 
  read.table(file.path("DukeWebSite","OVCclinicalinfo.csv"),
             skip=1,header=FALSE,sep=',',quote="",nrows=119,
             row.names=1)
clinicalDressman[1:3,]
dim(clinicalDressman)

tempHeaders <- 
  read.table(file.path("DukeWebSite","OVCclinicalinfo.csv"),
             header=FALSE,sep=',',nrows=1)
tempHeaders <- as.vector(apply(tempHeaders, 1, as.character))
tempHeaders

tempHeaders[tempHeaders=="Assigned Stage"] <- "Stage";
tempHeaders[tempHeaders=="GRADE"] <- "Grade";

colnames(clinicalDressman) <- tempHeaders[2:7];
clinicalDressman[1:3,]

rm(tempHeaders)



###################################################
### chunk number 3: fixSurvival
###################################################

tempSurv <- as.character(clinicalDressman$Survival)
tempAlive <- rep("Dead", 119);
tempAlive[grep("\\+",tempSurv)] <- "Alive"
table(tempAlive)

tempMonths <- as.integer(unlist(strsplit(tempSurv,"\\+")));

clinicalDressman$SurvMonths <- tempMonths;
clinicalDressman$Censoring <- as.factor(tempAlive);

clinicalDressman[1:3,]
rm(tempSurv, tempAlive, tempMonths)



###################################################
### chunk number 4: fixStage
###################################################

table(clinicalDressman$"Stage")
which(is.na((clinicalDressman$"Stage")))
rownames(clinicalDressman)[which(is.na((clinicalDressman$"Stage")))]



###################################################
### chunk number 5: fixGrade
###################################################

table(clinicalDressman$Grade);



###################################################
### chunk number 6: fixDebulk
###################################################

tempDebulk <- as.character(clinicalDressman$Debulk);
table(tempDebulk)
tempDebulk[grep("^Sub",tempDebulk)] <- "S"
tempDebulk[grep("^Opt",tempDebulk)] <- "O"
table(tempDebulk)
clinicalDressman$Debulk <- as.factor(tempDebulk)
table(clinicalDressman$Debulk)
levels(clinicalDressman$Debulk)



###################################################
### chunk number 7: fixResponse
###################################################

colnames(clinicalDressman)[6]
colnames(clinicalDressman)[6] <- "Response"
tempResp <- clinicalDressman$Response;

tempResp[clinicalDressman$Response == 0] <- "NR"
tempResp[clinicalDressman$Response == 1] <- "CR"
tempResp[1:3]

clinicalDressman$Response <- as.factor(tempResp);
clinicalDressman[1:3,]

rm(tempResp)



###################################################
### chunk number 8: getClinicalBild
###################################################

clinicalBild <- 
  read.table(file.path("OtherData","BildNature06",
                       "Ovarian_Clinical.csv"),
             header=TRUE,row.names=1,nrows=135,sep=",")
dim(clinicalBild)
clinicalBild[1:3,]

colnames(clinicalBild)
colnames(clinicalBild) <- c("SurvMonths","Censoring","Stage");

clinicalBild[1:3,]

tempCensor <- clinicalBild$Censoring
tempCensor[clinicalBild$Censoring == 0] <- "Alive"
tempCensor[clinicalBild$Censoring == 1] <- "Dead"
clinicalBild$Censoring <- as.factor(tempCensor)
clinicalBild[1:3,]



###################################################
### chunk number 9: getClinicalBerchuck
###################################################

clinicalBerchuck <- 
  read.table(file.path("OtherData","BerchuckClinCancRes05",
                       "arrayWebSiteClinicalData_2005.csv"),
             skip=2,header=FALSE,nrows=65,sep=",")
dim(clinicalBerchuck)
clinicalBerchuck[1:3,]

tempHeader <- 
  read.table(file.path("OtherData","BerchuckClinCancRes05",
                       "arrayWebSiteClinicalData_2005.csv"),
             skip=1,header=FALSE,nrows=1,sep=",")
colnames(clinicalBerchuck) <- 
  c("ArrayID", "CancerType", "AgeDx","Stage","Grade","Debulk")



###################################################
### chunk number 10: getBerchuckCELNames
###################################################

berchuckCELNames <- 
  dir(file.path("OtherData", "BerchuckClinCancRes05", "CEL_Files"))

berchuckCELNames[1:10]



###################################################
### chunk number 11: moreBerchuckParsing
###################################################

temp <- unlist(strsplit(berchuckCELNames,".cel"))
berchuckCELNames[1:2]
temp[1:2]
temp <- strsplit(temp,"_")
berchuckArrayIDs <- unlist(lapply(temp,function(x){x[2]}))
berchuckSampleIDs <- unlist(lapply(temp,function(x){x[4]}))
names(berchuckSampleIDs) <- berchuckArrayIDs

setdiff(berchuckArrayIDs,as.character(clinicalBerchuck$ArrayID))
setdiff(as.character(clinicalBerchuck$ArrayID),berchuckArrayIDs)



###################################################
### chunk number 12: checkNameMismatach
###################################################

berchuckCELNames[grep("2485_h133a",berchuckCELNames)]
load(file.path("RDataObjects","celFiles.Rda"))
celFiles[grep("2484_h133a",celFiles)]



###################################################
### chunk number 13: addLastPair
###################################################

berchuckSampleIDs <- c(berchuckSampleIDs, "3249")
berchuckSampleIDs[64:66]
names(berchuckSampleIDs)[64:66]
names(berchuckSampleIDs)[66] <- "2484"



###################################################
### chunk number 14: update08
###################################################

berchuckSampleIDs[berchuckSampleIDs == ".08"] <- "0.08";



###################################################
### chunk number 15: addBerchuckRownames
###################################################

rownames(clinicalBerchuck) <- 
  berchuckSampleIDs[as.character(clinicalBerchuck$ArrayID)]



###################################################
### chunk number 16: dressmanBildOverlap
###################################################

tempOverlap <- 
  intersect(rownames(clinicalDressman), rownames(clinicalBild));
length(tempOverlap)

setdiff(rownames(clinicalDressman), rownames(clinicalBild));
setdiff(rownames(clinicalBild), rownames(clinicalDressman));



###################################################
### chunk number 17: checkStageOverlap
###################################################

table(clinicalDressman[tempOverlap,"Stage"],
      clinicalBild[tempOverlap,"Stage"])



###################################################
### chunk number 18: checkSurvOverlap
###################################################

sum(clinicalDressman[tempOverlap,"SurvMonths"] ==
    clinicalBild[tempOverlap,"SurvMonths"])

tempOverlap[clinicalDressman[tempOverlap,"SurvMonths"] !=
            clinicalBild[tempOverlap,"SurvMonths"]]
clinicalDressman[c("D2432","D2668"),]
clinicalBild[c("D2432","D2668"),]



###################################################
### chunk number 19: checkCensorOverlap
###################################################

table(clinicalDressman[tempOverlap,"Censoring"],
      clinicalBild[tempOverlap,"Censoring"])

censorBad <- 
  tempOverlap[clinicalDressman[tempOverlap,"Censoring"] != 
              clinicalBild[tempOverlap,"Censoring"]]
censorBad



###################################################
### chunk number 20: whereBad
###################################################

clinicalDressman[censorBad,]
clinicalBild[censorBad,]

sort(clinicalDressman$SurvMonths)[100:119]



###################################################
### chunk number 21: berchuckWhereBad
###################################################

clinicalBerchuck[censorBad,]



###################################################
### chunk number 22: checkBerDreOverlap
###################################################

tempOverlapBerDre <- 
  intersect(rownames(clinicalBerchuck),rownames(clinicalDressman))
length(tempOverlapBerDre)
clinicalBerchuck[setdiff(rownames(clinicalBerchuck),
                         rownames(clinicalDressman)),]



###################################################
### chunk number 23: contrastBerDre
###################################################

table(clinicalDressman[tempOverlapBerDre,"Stage"],
      clinicalBerchuck[tempOverlapBerDre,"Stage"])

table(clinicalDressman[tempOverlapBerDre,"Grade"],
      clinicalBerchuck[tempOverlapBerDre,"Grade"])

table(clinicalDressman[tempOverlapBerDre,"Debulk"],
      clinicalBerchuck[tempOverlapBerDre,"Debulk"])



###################################################
### chunk number 24: contrastBerDreCens
###################################################

table(clinicalDressman[tempOverlapBerDre,"Censoring"],
      clinicalBerchuck[tempOverlapBerDre,"CancerType"])



###################################################
### chunk number 25: assembleClinicalInfo
###################################################

tempCensor <- clinicalDressman[,"Censoring"]
names(tempCensor) <- rownames(clinicalDressman)
tempCensor[censorBad]
tempCensor[censorBad] <- "Alive"
tempCensor["3102"] <- "Dead"
tempCensor[censorBad]
clinicalInfo <- 
  cbind(clinicalDressman[,c("SurvMonths", "Censoring")], 
        CensoringBild=tempCensor,
        clinicalDressman[,c("Response", "Stage", "Grade", 
                            "Debulk", "CA125 POST")])

clinicalInfo[1:5,]



###################################################
### chunk number 26: saveClin
###################################################

save(clinicalDressman, file=paste("RDataObjects", "clinicalDressman.Rda",
                         sep=.Platform$file.sep))
save(clinicalBild, file=paste("RDataObjects", "clinicalBild.Rda",
                     sep=.Platform$file.sep))
save(clinicalBerchuck, file=paste("RDataObjects", "clinicalBerchuck.Rda",
                         sep=.Platform$file.sep))
save(clinicalInfo, file=paste("RDataObjects", "clinicalInfo.Rda",
                     sep=.Platform$file.sep))



###################################################
### chunk number 27: sessionInfo
###################################################

sessionInfo();



