###################################################
### chunk number 1: options
###################################################

options(width=80);



###################################################
### chunk number 2: loadGeneList
###################################################

reportedGenes <- read.table(file.path("OtherData","gene_list.csv"),
                            sep=",",quote="",header=TRUE,
                            colClasses="character", strip.white=TRUE)
dim(reportedGenes)
reportedGenes[1:3,]



###################################################
### chunk number 3: loadGEOAnnotation
###################################################

h133aChipInfo <- read.table("OtherData/GEO/GPL96-3386.txt",
                            header=TRUE,skip=16,sep="\t",quote="",
                            row.names=1)
dim(h133aChipInfo)
colnames(h133aChipInfo)
h133aChipInfo[,"Gene.Title"] <- 
  as.character(h133aChipInfo[,"Gene.Title"]);
h133aChipInfo[,"Gene.Symbol"] <- 
  as.character(h133aChipInfo[,"Gene.Symbol"]);
h133aChipInfo[,"Representative.Public.ID"] <- 
  as.character(h133aChipInfo[,"Representative.Public.ID"]);



###################################################
### chunk number 4: findEasyMatches
###################################################

probesetMatches <- vector("list", 100)
for(i1 in 1:100){
  probesetMatches[[i1]] <- 
    rownames(h133aChipInfo)[h133aChipInfo$Rep ==
                            reportedGenes$Rep[i1]]
}

nMatches <- unlist(lapply(probesetMatches, length));
table(nMatches)



###################################################
### chunk number 5: focusOnDuples
###################################################

which(nMatches == 2)
probesetMatches[[which(nMatches == 2)[1]]]
probesetMatches[[which(nMatches == 2)[2]]]
reportedGenes[c(6,62),]
h133aChipInfo[h133aChipInfo$Rep == "AB033605",
              c("Gene.Title","Gene.Symbol")]
h133aChipInfo[h133aChipInfo$Rep == "NM_000291",
              c("Gene.Title","Gene.Symbol")]



###################################################
### chunk number 6: findBadRows
###################################################
badRows <- which(nMatches == 0);
badRows;


###################################################
### chunk number 7: checkNumber01
###################################################
reportedGenes[badRows[1],];
goodRows <- grep("P58 repressor", h133aChipInfo$Gene.Title);
as.character(h133aChipInfo[goodRows,"Gene.Title"]);
as.character(h133aChipInfo[goodRows,"Gene.Symbol"]);
as.character(h133aChipInfo[goodRows,"Representative.Public.ID"]);
rownames(h133aChipInfo[goodRows,])
probesetMatches[[badRows[1]]] <- rownames(h133aChipInfo[goodRows,]);


###################################################
### chunk number 8: checkNumber02
###################################################
reportedGenes[badRows[2],];
goodRows <- grep("alpha-2-macroglobulin receptor", h133aChipInfo$Gene.Title);
as.character(h133aChipInfo[goodRows,"Gene.Title"]);
as.character(h133aChipInfo[goodRows,"Gene.Symbol"]);
as.character(h133aChipInfo[goodRows,"Representative.Public.ID"]);
rownames(h133aChipInfo[goodRows,])
probesetMatches[[badRows[2]]] <- rownames(h133aChipInfo[goodRows,]);



###################################################
### chunk number 9: checkNumber03
###################################################
reportedGenes[badRows[3],];
goodRows <- grep("DiGeorge syndrome critical region gene 6", 
                 h133aChipInfo$Gene.Title);
as.character(h133aChipInfo[goodRows,"Gene.Title"]);
goodRows <- grep("DiGeorge syndrome critical region gene 6 ///", 
                 h133aChipInfo$Gene.Title);
as.character(h133aChipInfo[goodRows,"Gene.Symbol"]);
as.character(h133aChipInfo[goodRows,"Representative.Public.ID"]);
rownames(h133aChipInfo[goodRows,])
probesetMatches[[badRows[3]]] <- rownames(h133aChipInfo[goodRows,]);



###################################################
### chunk number 10: checkNumber04
###################################################
reportedGenes[badRows[4],];
goodRows <- grep("TRF1-interacting", 
                 h133aChipInfo$Gene.Title);
as.character(h133aChipInfo[goodRows,"Gene.Title"]);
goodRows <- grep("TRF1-interacting ankyrin-related ADP-ribose polymerase 2", 
                 h133aChipInfo$Gene.Title);
as.character(h133aChipInfo[goodRows,"Gene.Symbol"]);
as.character(h133aChipInfo[goodRows,"Representative.Public.ID"]);
rownames(h133aChipInfo[goodRows,])
probesetMatches[[badRows[4]]] <- rownames(h133aChipInfo[goodRows,]);



###################################################
### chunk number 11: checkNumber05
###################################################
reportedGenes[badRows[5],];
goodRows <- grep("mitochondrial ribosomal protein L9", 
                 h133aChipInfo$Gene.Title);
as.character(h133aChipInfo[goodRows,"Gene.Title"]);
as.character(h133aChipInfo[goodRows,"Gene.Symbol"]);
as.character(h133aChipInfo[goodRows,"Representative.Public.ID"]);
rownames(h133aChipInfo[goodRows,])
probesetMatches[[badRows[5]]] <- rownames(h133aChipInfo[goodRows,]);



###################################################
### chunk number 12: checkNumber06
###################################################
reportedGenes[badRows[6],];
goodRows <- grep("variant Gaucher disease", 
                 h133aChipInfo$Gene.Title);
as.character(h133aChipInfo[goodRows,"Gene.Title"]);
as.character(h133aChipInfo[goodRows,"Gene.Symbol"]);
as.character(h133aChipInfo[goodRows,"Representative.Public.ID"]);
rownames(h133aChipInfo[goodRows,])
probesetMatches[[badRows[6]]] <- rownames(h133aChipInfo[goodRows,]);



###################################################
### chunk number 13: checkNumber07
###################################################
reportedGenes[badRows[7],];
goodRows <- grep("oxoglutarate carrier", h133aChipInfo$Gene.Title);
as.character(h133aChipInfo[goodRows,"Gene.Title"]);
as.character(h133aChipInfo[goodRows,"Gene.Symbol"]);
as.character(h133aChipInfo[goodRows,"Representative.Public.ID"]);
rownames(h133aChipInfo[goodRows,])
probesetMatches[[badRows[7]]] <- rownames(h133aChipInfo[goodRows,]);



###################################################
### chunk number 14: checkNumber08
###################################################
reportedGenes[badRows[8],];
goodRows <- grep("mitochondrial F0 complex, subunit d", 
                 h133aChipInfo$Gene.Title);
as.character(h133aChipInfo[goodRows,"Gene.Title"]);
as.character(h133aChipInfo[goodRows,"Gene.Symbol"]);
as.character(h133aChipInfo[goodRows,"Representative.Public.ID"]);
rownames(h133aChipInfo[goodRows,])
probesetMatches[[badRows[8]]] <- rownames(h133aChipInfo[goodRows,]);



###################################################
### chunk number 15: checkNumber09
###################################################
reportedGenes[badRows[9],];
goodRows <- grep("H/ACA small nucleolar RNPs", h133aChipInfo$Gene.Title);
as.character(h133aChipInfo[goodRows,"Gene.Title"]);
goodRows <- grep("nucleolar protein family A, member 3", 
                 h133aChipInfo$Gene.Title);
as.character(h133aChipInfo[goodRows,"Gene.Symbol"]);
as.character(h133aChipInfo[goodRows,"Representative.Public.ID"]);
rownames(h133aChipInfo[goodRows,])
probesetMatches[[badRows[9]]] <- rownames(h133aChipInfo[goodRows,]);



###################################################
### chunk number 16: checkNumber10
###################################################
reportedGenes[badRows[10],];
goodRows <- grep("SHANK", h133aChipInfo$Gene.Title);
as.character(h133aChipInfo[goodRows,"Gene.Title"]);
as.character(h133aChipInfo[goodRows,"Gene.Symbol"]);
as.character(h133aChipInfo[goodRows,"Representative.Public.ID"]);
rownames(h133aChipInfo[goodRows,])
probesetMatches[[badRows[10]]] <- rownames(h133aChipInfo[goodRows,]);



###################################################
### chunk number 17: checkNumber11
###################################################
reportedGenes[badRows[11],];
goodRows <- grep("atrionatriuretic peptide receptor A", 
                 h133aChipInfo$Gene.Title);
as.character(h133aChipInfo[goodRows,"Gene.Title"]);
as.character(h133aChipInfo[goodRows,"Gene.Symbol"]);
as.character(h133aChipInfo[goodRows,"Representative.Public.ID"]);
rownames(h133aChipInfo[goodRows,])
probesetMatches[[badRows[11]]] <- rownames(h133aChipInfo[goodRows,]);



###################################################
### chunk number 18: recheckMatches
###################################################

nMatches <- unlist(lapply(probesetMatches, length))
table(nMatches)



###################################################
### chunk number 19: buildReportedGenesTable
###################################################

reportedProbesets <- unlist(probesetMatches);
temp <- match(c("Gene.Symbol", 
                "Representative.Public.ID", 
                "Gene.Title"), 
              colnames(h133aChipInfo));
reportedGenesGEO <- h133aChipInfo[reportedProbesets, temp];



###################################################
### chunk number 20: checkTable
###################################################

length(unique(reportedGenesGEO[,"Gene.Symbol"]));
length(unique(reportedGenesGEO[,"Representative.Public.ID"]));
length(unique(reportedGenesGEO[,"Gene.Title"]));



###################################################
### chunk number 21: checkMultipleOdd
###################################################
table(reportedGenesGEO[,"Gene.Symbol"
                       ])[table(reportedGenesGEO[,"Gene.Symbol"]) > 1];
which(reportedGenesGEO$Gene.Symbol == "LRP1")
which(reportedGenesGEO$Gene.Symbol == "MRPL9")
which(reportedGenesGEO$Gene.Symbol == "NPR1")
which(reportedGenesGEO$Gene.Symbol == "PGK1")
which(reportedGenesGEO$Gene.Symbol == "PSAP")
which(reportedGenesGEO$Gene.Symbol == "PSMD4")
which(reportedGenesGEO$Gene.Symbol == "SLC25A11")
which(reportedGenesGEO$Gene.Symbol == "TPR")



###################################################
### chunk number 22: checkOdd
###################################################
reportedGenesGEO[which(reportedGenesGEO$Gene.Symbol == "TPR"),]


###################################################
### chunk number 23: saveStuff
###################################################

save(reportedGenesGEO, file=paste("RDataObjects","reportedGenesGEO.Rda",
                         sep=.Platform$file.sep));
save(h133aChipInfo, file=paste("RDataObjects","h133aChipInfo.Rda",
                      sep=.Platform$file.sep));



###################################################
### chunk number 24: sessionInfo
###################################################

sessionInfo();



