###################################################
### chunk number 1: options
###################################################

options(width=80);



###################################################
### chunk number 2: getLibraries
###################################################

library(affy)



###################################################
### chunk number 3: getData
###################################################

load(file.path("RDataObjects","celFiles.Rda"))
load(file.path("RDataObjects","clinicalInfo.Rda"))



###################################################
### chunk number 4: getCelInfo
###################################################

celDatHeaders <- celFiles;
for(i1 in 1:length(celDatHeaders)){

  temp <- 
    read.celfile.header(file.path("DukeWebSite", "PlatinumJCO", 
                                  celFiles[i1]),
                        info="full");
  celDatHeaders[i1] <- temp$DatHeader
  
}

celDatHeaders[1:3]
celDatHeaders[117:119]



###################################################
### chunk number 5: parseToGetDates
###################################################

tempDate1 <- strsplit(celDatHeaders, "2\\.0 ")
tempDate1[1]
tempDate2 <- unlist(lapply(tempDate1, function(x){x[2]}))
tempDate2[1]
tempDate3 <- 
  unlist(lapply(tempDate2, function(x){substr(x, 1, 17)}))
tempDate3[1]
celRunDate <- as.Date(tempDate3, format="%m/%d/%y %H:%M:%S")
names(celRunDate) <- names(tempDate3)
celRunDate[1:3]

celRunDate <- celRunDate[rownames(clinicalInfo)];
celRunDate[1:3]

rm(tempDate1, tempDate2, tempDate3)



###################################################
### chunk number 6: tableRunDates
###################################################
table(celRunDate)


###################################################
### chunk number 7: plotRunDates
###################################################

plot(sort(celRunDate),
     xlab="Index",
     ylab="Sorted Run Date (Days Since 1970-01-01)",
     main="CEL File Run Dates")



###################################################
### chunk number 8: checkNames
###################################################

names(celRunDate[celRunDate < "2004-03-09"])
names(celRunDate[celRunDate >= "2004-03-09"])
sum(celRunDate < "2004-03-09")



###################################################
### chunk number 9: checkRecentNames
###################################################

table(celRunDate[celRunDate >= "2004-03-09"],
      substr(names(celRunDate[celRunDate >= "2004-03-09"]),1,1))



###################################################
### chunk number 10: tableDateByStage
###################################################

table(celRunDate,clinicalInfo$Stage)



###################################################
### chunk number 11: tableDateByGrade
###################################################

table(celRunDate,clinicalInfo$Grade)



###################################################
### chunk number 12: tableDateByDebulk
###################################################

table(celRunDate,clinicalInfo$Debulk)



###################################################
### chunk number 13: tableDateByResponse
###################################################

table(celRunDate,clinicalInfo$Response)



###################################################
### chunk number 14: plotSurvCensDre
###################################################

plot(celRunDate,clinicalInfo$SurvMonths,
     xlab="Run Date",
     ylab="Survival In Months",
     main="Survival by Run Date, Censoring (red) from Dressman et al")
points(celRunDate[clinicalInfo$Censoring=="Alive"],
       clinicalInfo$SurvMonths[clinicalInfo$Censoring=="Alive"],
       pch=3,cex=3,col="red")



###################################################
### chunk number 15: plotSurvCensBild
###################################################

plot(celRunDate,clinicalInfo$SurvMonths,
     xlab="Run Date",
     ylab="Survival In Months",
     main="Survival by Run Date, Censoring (red) from Bild et al")
points(celRunDate[clinicalInfo$CensoringBild=="Alive"],
       clinicalInfo$SurvMonths[clinicalInfo$CensoringBild=="Alive"],
       pch=3,cex=3,col="red")



###################################################
### chunk number 16: plotSurvBerchuckSamples
###################################################

plot(celRunDate[celRunDate < "2004-03-09"],
     clinicalInfo$SurvMonths[celRunDate < "2004-03-09"],
     xlab="Run Date, 2003-2004",
     ylab="Survival In Months",
     main="Survival by Run Date, Berchuck et al Samples")



###################################################
### chunk number 17: saveStuff
###################################################

save(celRunDate, file=paste("RDataObjects","celRunDate.Rda",
                   sep=.Platform$file.sep));



###################################################
### chunk number 18: sessionInfo
###################################################

sessionInfo();



