###################################################
### chunk number 1: options
###################################################

options(width=80);



###################################################
### chunk number 2: loadLibraries
###################################################

library(affy)
library(ClassComparison)
library(ClassDiscovery)



###################################################
### chunk number 3: loadRawData
###################################################

load(file.path("RDataObjects","ovcaRMAFromCEL.Rda"))
load(file.path("RDataObjects","ovcaRMAFromXLS.Rda"))
load(file.path("RDataObjects","reportedGenesGEO.Rda"))
load(file.path("RDataObjects","clinicalInfo.Rda"))
load(file.path("RDataObjects","celRunDate.Rda"))



###################################################
### chunk number 4: orderData
###################################################

ovcaRMAFromCEL <- ovcaRMAFromCEL[,rownames(clinicalInfo)]
ovcaRMAFromXLS <- ovcaRMAFromXLS[,rownames(clinicalInfo)]
celRunDate <- celRunDate[rownames(clinicalInfo)];



###################################################
### chunk number 5: getTFromCEL
###################################################

tFromCEL <- MultiTtest(ovcaRMAFromCEL, clinicalInfo$Response)
tFromXLS <- MultiTtest(ovcaRMAFromXLS, clinicalInfo$Response)



###################################################
### chunk number 6: bumFromCEL
###################################################

bumFromCEL <- Bum(tFromCEL@p.values);
image(bumFromCEL)



###################################################
### chunk number 7: bumFromXLS
###################################################

bumFromXLS <- Bum(tFromXLS@p.values);
image(bumFromXLS)



###################################################
### chunk number 8: plotReportedGenesFromCEL
###################################################

plot(sort(tFromCEL@p.values[match(rownames(reportedGenesGEO),
                                  rownames(ovcaRMAFromCEL))]),
     xlab="Index",
     ylab="NR vs CR t-test p-value",
     main="Sorted P-values of Genes Reported as Important, CEL")
abline(0,1/dim(reportedGenesGEO)[1])



###################################################
### chunk number 9: plotReportedGenesFromXLS
###################################################

plot(sort(tFromXLS@p.values[match(rownames(reportedGenesGEO),
                                  rownames(ovcaRMAFromXLS))]),
     xlab="Index",
     ylab="NR vs CR t-test p-value",
     main="Sorted P-values of Genes Reported as Important, XLS")
abline(0,1/dim(reportedGenesGEO)[1])



###################################################
### chunk number 10: defColors
###################################################

respColors <- rep("blue", 119)
respColors[clinicalInfo$Response=="NR"] <- "red";



###################################################
### chunk number 11: reportedCELHeatmap
###################################################

heatmap(ovcaRMAFromCEL[rownames(reportedGenesGEO),],
        ColSideColors=respColors)



###################################################
### chunk number 12: reportedXLSHeatmap
###################################################

heatmap(as.matrix(ovcaRMAFromXLS[rownames(reportedGenesGEO),]),
        ColSideColors=respColors)



###################################################
### chunk number 13: heatmapPeeking
###################################################

heatmap(ovcaRMAFromCEL[tFromCEL@p.values <= sort(tFromCEL@p.values)[100],],
        ColSideColors=respColors)



###################################################
### chunk number 14: plotBestGene
###################################################

plot(celRunDate, ovcaRMAFromCEL[which.min(tFromCEL@p.values),],
     xlab="Run Date", 
     ylab=paste("Expression Values of",
       rownames(ovcaRMAFromCEL)[which.min(tFromCEL@p.values)]),
     main="Expression by Run Date, Most Significant CR/NR Difference")
points(celRunDate[clinicalInfo$Response=="NR"], 
       ovcaRMAFromCEL[which.min(tFromCEL@p.values),
                      clinicalInfo$Response=="NR"], 
       col="red", pch=2, cex=3)



###################################################
### chunk number 15: defineRunBatch
###################################################

runBatch <- rep(6, 119);
runBatch[celRunDate == "2002-09-20"] <- 1;

runBatch[celRunDate == "2002-10-23"] <- 2;

runBatch[celRunDate == "2002-11-12"] <- 2;

runBatch[celRunDate == "2002-12-16"] <- 3;
runBatch[celRunDate == "2002-12-21"] <- 3;
runBatch[celRunDate == "2003-01-03"] <- 3;

runBatch[celRunDate == "2003-05-30"] <- 4;
runBatch[celRunDate == "2003-06-26"] <- 4;

runBatch[celRunDate == "2004-03-09"] <- 5;
runBatch[celRunDate == "2004-03-16"] <- 5;
runBatch[celRunDate == "2004-04-20"] <- 5;

runBatch[celRunDate == "2004-05-18"] <- 6;
runBatch[celRunDate == "2004-05-21"] <- 6;
runBatch[celRunDate == "2004-05-27"] <- 6;
runBatch[celRunDate == "2004-06-22"] <- 6;
runBatch[celRunDate == "2004-06-23"] <- 6;

runBatch <- as.factor(runBatch);
names(runBatch) <- names(celRunDate);



###################################################
### chunk number 16: buildModels
###################################################

batchModelForm <- Y ~ runBatch;
batchModelLMAll <- MultiLinearModel(batchModelForm,
                                    data.frame(runBatch=runBatch),
                                    ovcaRMAFromCEL)

ovcaRMAFromCELResids <- ovcaRMAFromCEL - t(batchModelLMAll@predictions);

responseModelForm <- Y ~ Response;
responseModelLMAll <- 
  MultiLinearModel(responseModelForm,
                   data.frame(Response=clinicalInfo$Response),
                   ovcaRMAFromCELResids);



###################################################
### chunk number 17: buildBUMs
###################################################

bumBatch <- Bum(batchModelLMAll@p.values)
bumRespBatch <- Bum(responseModelLMAll@p.values)



###################################################
### chunk number 18: bumBatchImage
###################################################

image(bumBatch);



###################################################
### chunk number 19: bumRespBatchImage
###################################################

image(bumRespBatch)



###################################################
### chunk number 20: buildXLSModels
###################################################

batchModelXLSForm <- Y ~ runBatch;
batchModelXLSLMAll <- MultiLinearModel(batchModelForm,
                                    data.frame(runBatch=runBatch),
                                    ovcaRMAFromXLS)

ovcaRMAFromXLSResids <- 
  ovcaRMAFromXLS - t(batchModelXLSLMAll@predictions);

responseModelXLSForm <- Y ~ Response;
responseModelXLSLMAll <- 
  MultiLinearModel(responseModelXLSForm,
                   data.frame(Response=clinicalInfo$Response),
                   ovcaRMAFromXLSResids);



###################################################
### chunk number 21: bumXLSBatch
###################################################

bumXLSBatch <- Bum(batchModelXLSLMAll@p.values)
bumRespXLSBatch <- Bum(responseModelXLSLMAll@p.values)



###################################################
### chunk number 22: bumBatchXLSImage
###################################################

image(bumXLSBatch)



###################################################
### chunk number 23: bumRespBatchXLSImage
###################################################

image(bumRespXLSBatch)



###################################################
### chunk number 24: saveStuff
###################################################

save(runBatch, file=paste("RDataObjects","runBatch.Rda",
                   sep=.Platform$file.sep));
save(ovcaRMAFromCELResids, 
     file=paste("RDataObjects","ovcaRMAFromCELResids.Rda",
                   sep=.Platform$file.sep));
save(ovcaRMAFromXLSResids, 
     file=paste("RDataObjects","ovcaRMAFromXLSResids.Rda",
                   sep=.Platform$file.sep));



###################################################
### chunk number 25: sessionInfo
###################################################

sessionInfo();



