###################################################
### chunk number 1: options
###################################################

options(width=80);



###################################################
### chunk number 2: getLibraries
###################################################

library(affy)
library(ClassComparison)
library(ClassDiscovery)



###################################################
### chunk number 3: loadOtherData
###################################################

load(file.path("RDataObjects","ovcaRMAFromCEL.Rda"))
load(file.path("RDataObjects","ovcaRMAFromXLS.Rda"))
load(file.path("RDataObjects","ovcaRMAFromCELResids.Rda"))
load(file.path("RDataObjects","ovcaRMAFromXLSResids.Rda"))
load(file.path("RDataObjects","celRunDate.Rda"))
load(file.path("RDataObjects","clinicalInfo.Rda"))



###################################################
### chunk number 4: sortOtherData
###################################################

ovcaRMAFromCEL <- ovcaRMAFromCEL[,rownames(clinicalInfo)]
ovcaRMAFromXLS <- ovcaRMAFromXLS[,rownames(clinicalInfo)]
ovcaRMAFromCELResids <- ovcaRMAFromCELResids[,rownames(clinicalInfo)]
ovcaRMAFromXLSResids <- ovcaRMAFromXLSResids[,rownames(clinicalInfo)]
celRunDate <- celRunDate[rownames(clinicalInfo)]



###################################################
### chunk number 5: getRMAFomCEL
###################################################

pathwayCELDir <- file.path("OtherData", "BildNature06", "Andrea")
pathwayCELs <- dir(pathwayCELDir);
rda <- "pathwayRMAEset";
rdaFile <- paste("RDataObjects",paste(rda, "Rda", sep="."),
                 sep=.Platform$file.sep);
if(file.exists(rdaFile)){
  cat(paste("loading", rda, "from cache\n"))
  load(rdaFile);
}else{
  pathwayRMAEset <- 
    justRMA(filenames=paste(pathwayCELDir, pathwayCELs,
              sep=.Platform$file.sep));
  save(pathwayRMAEset, file=rdaFile);
}



###################################################
### chunk number 6: getExprs
###################################################

pathwayRMA <- exprs(pathwayRMAEset);

tempNames <- pathwayCELs;
tempNames[1:3]
tempNames2 <- strsplit(tempNames, "\\+_");
tempNames2 <- unlist(lapply(tempNames2, function(x){x[2]}));
tempNames2[1:3]
tempNames3 <- unlist(strsplit(tempNames2, "_cel.txt"))
tempNames3[1:3]

pathwayShortNames <- tempNames3;
names(pathwayCELs) <- pathwayShortNames;
colnames(pathwayRMA) <- pathwayShortNames;

rm(tempNames, tempNames2, tempNames3)



###################################################
### chunk number 7: loadPathwayGeneLists
###################################################

pathways <- c("Bcat","E2F3","Myc","Ras","Src");
pathwayGenesBild <- vector("list",length(pathways))
names(pathwayGenesBild) <- pathways;
for(i1 in 1:length(pathways)){
  pathwayGenesBild[[i1]] <- 
    read.table(file.path("OtherData", "BildNature06",
                         paste(pathways[i1], "txt", sep=".")),
               colClasses="character")[,1]
}

lapply(pathwayGenesBild, length)
pathwayGenesBild$Bcat[1:3]



###################################################
### chunk number 8: getOurLists
###################################################

pathwayGenes <- vector("list",length(pathways))
names(pathwayGenes) <- pathways;

tempGFP <- pathwayRMA[,grep("GFP",colnames(pathwayRMA),ignore.case=TRUE)]
tempPvalues <- matrix(0,dim(pathwayRMA)[1],length(pathways));
rownames(tempPvalues) <- rownames(pathwayRMA);
colnames(tempPvalues) <- pathways;

for(i1 in 1:length(pathways)){

  tempPathway <- 
    pathwayRMA[,grep(pathways[i1],colnames(pathwayRMA),ignore.case=TRUE)]
  tempFactor <- rep(c("Baseline", "Experiment"),
                    times=c(dim(tempGFP)[2], dim(tempPathway)[2]))
  tempFactor <- as.factor(tempFactor)
  tempT <- MultiTtest(cbind(tempGFP, tempPathway), tempFactor);

  tempPvalues[,i1] <- tempT@p.values;

  tempCutoff <- 
    sort(tempT@p.values)[length(pathwayGenesBild[[pathways[i1]]])]
                      
  pathwayGenes[[pathways[i1]]] <- 
    rownames(pathwayRMA)[tempT@p.values <= tempCutoff]

}



###################################################
### chunk number 9: checkOverlap
###################################################

tempOverlap <- matrix(0,length(pathways),4)
rownames(tempOverlap) <- pathways;
colnames(tempOverlap) <- 
  c("nGenes", "nOverlap", "minPvalue", "maxPvalue")

for(i1 in 1:length(pathways)){

  tempOverlap[i1,"nGenes"] <- length(pathwayGenes[[i1]])
  tempOverlap[i1,"nOverlap"] <- 
    length(intersect(pathwayGenes[[i1]], pathwayGenesBild[[i1]]))
  tempOverlap[i1,3:4] <- 
    range(tempPvalues[pathwayGenesBild[[i1]],pathways[i1]])
                                           
}

tempOverlap;



###################################################
### chunk number 10: checkMissingProbesets
###################################################

unlist(lapply(pathwayGenes,function(x){grep("^2000",x)}))
unlist(lapply(pathwayGenesBild,function(x){grep("^2000",x)}))

pathwayGenes$Myc[16]
pathwayGenesBild$Myc[141]



###################################################
### chunk number 11: getU133ALists
###################################################

pathwayGenesU133A <- pathwayGenes;
for(i1 in 1:length(pathwayGenesU133A)){
  pathwayGenesU133A[[i1]] <- intersect(pathwayGenes[[i1]],
                                 rownames(ovcaRMAFromCEL));
}

pathwayGenesBildU133A <- pathwayGenesBild;
for(i1 in 1:length(pathwayGenesBildU133A)){
  pathwayGenesBildU133A[[i1]] <- intersect(pathwayGenesBild[[i1]],
                                 rownames(ovcaRMAFromCEL));
}

unlist(lapply(pathwayGenes,length))
unlist(lapply(pathwayGenesU133A,length))
unlist(lapply(pathwayGenesBildU133A,length))



###################################################
### chunk number 12: getWeights
###################################################

pathwayWeightsU133A <- vector("list",length(pathways))
names(pathwayWeightsU133A) <- pathways;
pathwayDataU133A <- vector("list",length(pathways))
names(pathwayDataU133A) <- pathways;

tempGFP <- pathwayRMA[,grep("GFP",colnames(pathwayRMA),ignore.case=TRUE)]

for(i1 in 1:length(pathways)){

  tempPathway <- 
    pathwayRMA[,grep(pathways[i1],colnames(pathwayRMA),ignore.case=TRUE)]

  tempData <- cbind(tempGFP, tempPathway);
  tempData <- tempData[pathwayGenesU133A[[i1]],];

  tempData <- t(scale(t(tempData)));

  pathwayDataU133A[[i1]] <- tempData;

  tempWeights <- svd(tempData)$u[,1];
  names(tempWeights) <- pathwayGenesU133A[[i1]];

  pathwayWeightsU133A[[i1]] <- tempWeights;

}



###################################################
### chunk number 13: getCellLineScores
###################################################

pathwayCellScoresU133A <- vector("list",length(pathways))
names(pathwayCellScoresU133A) <- pathways

for(i1 in 1:length(pathways)){

  tempScores <- 
    pathwayWeightsU133A[[i1]] %*% pathwayDataU133A[[i1]]

  if(median(tempScores[grep("GFP",colnames(tempScores))]) > 0){
    pathwayWeightsU133A[[i1]] <- -pathwayWeightsU133A[[i1]];
    tempScores <- -tempScores;
  }

  pathwayCellScoresU133A[[i1]] <- tempScores[1,]

}



###################################################
### chunk number 14: plotLots
###################################################

par(mfrow=c(3,length(pathways)))

for(i1 in 1:length(pathways)){
  image(1:dim(pathwayDataU133A[[i1]])[1],
        1:dim(pathwayDataU133A[[i1]])[2],
        pathwayDataU133A[[i1]],
        xlab="Genes", ylab="Samples", main=pathways[i1])
}

for(i1 in 1:length(pathways)){
  plot(pathwayWeightsU133A[[i1]], xlab="Genes", ylab="Weights")
}

for(i1 in 1:length(pathways)){
  plot(pathwayCellScoresU133A[[i1]],
       xlab=paste("GFP Left,", pathways[i1], "Right"),
       ylab="Scores")
}

par(mfrow=c(1,1))



###################################################
### chunk number 15: getBildWeightsAndScores
###################################################

pathwayWeightsBildU133A <- vector("list",length(pathways))
names(pathwayWeightsBildU133A) <- pathways;
pathwayDataBildU133A <- vector("list",length(pathways))
names(pathwayDataBildU133A) <- pathways;

tempGFP <- pathwayRMA[,grep("GFP",colnames(pathwayRMA),ignore.case=TRUE)]

for(i1 in 1:length(pathways)){

  tempPathway <- 
    pathwayRMA[,grep(pathways[i1],colnames(pathwayRMA),ignore.case=TRUE)]

  tempData <- cbind(tempGFP, tempPathway);
  tempData <- tempData[pathwayGenesBildU133A[[i1]],];

  tempData <- t(scale(t(tempData)));

  pathwayDataBildU133A[[i1]] <- tempData;

  tempWeights <- svd(tempData)$u[,1];
  names(tempWeights) <- pathwayGenesBildU133A[[i1]];

  pathwayWeightsBildU133A[[i1]] <- tempWeights;

}


pathwayCellScoresBildU133A <- vector("list",length(pathways))
names(pathwayCellScoresBildU133A) <- pathways

for(i1 in 1:length(pathways)){

  tempScores <- 
    pathwayWeightsBildU133A[[i1]] %*% pathwayDataBildU133A[[i1]]

  if(median(tempScores[grep("GFP",colnames(tempScores))]) > 0){
    pathwayWeightsBildU133A[[i1]] <- -pathwayWeightsBildU133A[[i1]];
    tempScores <- -tempScores;
  }

  pathwayCellScoresBildU133A[[i1]] <- tempScores[1,]

}



###################################################
### chunk number 16: plotScores
###################################################

par(mfrow=c(2,3))

for(i1 in 1:length(pathways)){
  plot(pathwayCellScoresU133A[[i1]], pathwayCellScoresBildU133A[[i1]],
       xlab="Scores", ylab="Scores (Bild)", main=pathways[i1])
}

par(mfrow=c(1,1))



###################################################
### chunk number 17: getTumorScoresCEL
###################################################

pathwayScoresCEL <- vector("list",length(pathways))
names(pathwayScoresCEL) <- pathways

pathwayDataCEL <- vector("list",length(pathways))
names(pathwayDataCEL) <- pathways;

for(i1 in 1:length(pathways)){

  tempData <- ovcaRMAFromCEL[pathwayGenesU133A[[i1]],
                             rownames(clinicalInfo)];

  tempData <- t(scale(t(tempData)));

  pathwayDataCEL[[i1]] <- tempData;

  tempScores <- 
    pathwayWeightsU133A[[i1]] %*% pathwayDataCEL[[i1]]

  pathwayScoresCEL[[i1]] <- tempScores[1,]

}



###################################################
### chunk number 18: getTumorScoresXLS
###################################################

pathwayScoresXLS <- vector("list",length(pathways))
names(pathwayScoresXLS) <- pathways

pathwayDataXLS <- vector("list",length(pathways))
names(pathwayDataXLS) <- pathways;

for(i1 in 1:length(pathways)){

  genesInXLS <- intersect(pathwayGenesU133A[[i1]], 
                          rownames(ovcaRMAFromXLS))

  tempData <- ovcaRMAFromXLS[genesInXLS,
                             rownames(clinicalInfo)];

  tempData <- t(scale(t(tempData)));

  pathwayDataXLS[[i1]] <- tempData;

  tempScores <- 
    pathwayWeightsU133A[[i1]][genesInXLS] %*% pathwayDataXLS[[i1]]

  pathwayScoresXLS[[i1]] <- tempScores[1,]

}



###################################################
### chunk number 19: getTumorScoresCELBild
###################################################

pathwayScoresCELBild <- vector("list",length(pathways))
names(pathwayScoresCELBild) <- pathways

pathwayDataCELBild <- vector("list",length(pathways))
names(pathwayDataCELBild) <- pathways;

for(i1 in 1:length(pathways)){

  tempData <- ovcaRMAFromCEL[pathwayGenesBildU133A[[i1]],
                             rownames(clinicalInfo)];

  tempData <- t(scale(t(tempData)));

  pathwayDataCELBild[[i1]] <- tempData;

  tempScores <- 
    pathwayWeightsBildU133A[[i1]] %*% pathwayDataCELBild[[i1]]

  pathwayScoresCELBild[[i1]] <- tempScores[1,]

}



###################################################
### chunk number 20: getTumorScoresXLSBild
###################################################

pathwayScoresXLSBild <- vector("list",length(pathways))
names(pathwayScoresXLSBild) <- pathways

pathwayDataXLSBild <- vector("list",length(pathways))
names(pathwayDataXLSBild) <- pathways;

for(i1 in 1:length(pathways)){

  genesInXLS <- intersect(pathwayGenesBildU133A[[i1]], 
                          rownames(ovcaRMAFromXLS))

  tempData <- ovcaRMAFromXLS[genesInXLS,
                             rownames(clinicalInfo)];

  tempData <- t(scale(t(tempData)));

  pathwayDataXLSBild[[i1]] <- tempData;

  tempScores <- 
    pathwayWeightsBildU133A[[i1]][genesInXLS] %*% 
      pathwayDataXLSBild[[i1]]

  pathwayScoresXLSBild[[i1]] <- tempScores[1,]

}



###################################################
### chunk number 21: getTumorScoresCELBatch
###################################################

pathwayScoresCELBatch <- vector("list",length(pathways))
names(pathwayScoresCELBatch) <- pathways

pathwayDataCELBatch <- vector("list",length(pathways))
names(pathwayDataCELBatch) <- pathways;

for(i1 in 1:length(pathways)){

  tempData <- ovcaRMAFromCELResids[pathwayGenesU133A[[i1]],
                                   rownames(clinicalInfo)];

  tempData <- t(scale(t(tempData)));

  pathwayDataCELBatch[[i1]] <- tempData;

  tempScores <- 
    pathwayWeightsU133A[[i1]] %*% pathwayDataCELBatch[[i1]]

  pathwayScoresCELBatch[[i1]] <- tempScores[1,]

}



###################################################
### chunk number 22: getTumorScoresXLSBatch
###################################################

pathwayScoresXLSBatch <- vector("list",length(pathways))
names(pathwayScoresXLSBatch) <- pathways

pathwayDataXLSBatch <- vector("list",length(pathways))
names(pathwayDataXLSBatch) <- pathways;

for(i1 in 1:length(pathways)){

  genesInXLS <- intersect(pathwayGenesU133A[[i1]], 
                          rownames(ovcaRMAFromXLSResids))

  tempData <- ovcaRMAFromXLSResids[genesInXLS,
                             rownames(clinicalInfo)];

  tempData <- t(scale(t(tempData)));

  pathwayDataXLSBatch[[i1]] <- tempData;

  tempScores <- 
    pathwayWeightsU133A[[i1]][genesInXLS] %*% pathwayDataXLSBatch[[i1]]

  pathwayScoresXLSBatch[[i1]] <- tempScores[1,]

}



###################################################
### chunk number 23: getTumorScoresCELBildBatch
###################################################

pathwayScoresCELBildBatch <- vector("list",length(pathways))
names(pathwayScoresCELBildBatch) <- pathways

pathwayDataCELBildBatch <- vector("list",length(pathways))
names(pathwayDataCELBildBatch) <- pathways;

for(i1 in 1:length(pathways)){

  tempData <- ovcaRMAFromCELResids[pathwayGenesBildU133A[[i1]],
                                   rownames(clinicalInfo)];

  tempData <- t(scale(t(tempData)));

  pathwayDataCELBildBatch[[i1]] <- tempData;

  tempScores <- 
    pathwayWeightsBildU133A[[i1]] %*% pathwayDataCELBildBatch[[i1]]

  pathwayScoresCELBildBatch[[i1]] <- tempScores[1,]

}



###################################################
### chunk number 24: getTumorScoresXLSBildBatch
###################################################

pathwayScoresXLSBildBatch <- vector("list",length(pathways))
names(pathwayScoresXLSBildBatch) <- pathways

pathwayDataXLSBildBatch <- vector("list",length(pathways))
names(pathwayDataXLSBildBatch) <- pathways;

for(i1 in 1:length(pathways)){

  genesInXLS <- intersect(pathwayGenesBildU133A[[i1]], 
                          rownames(ovcaRMAFromXLSResids))

  tempData <- ovcaRMAFromXLSResids[genesInXLS,
                             rownames(clinicalInfo)];

  tempData <- t(scale(t(tempData)));

  pathwayDataXLSBildBatch[[i1]] <- tempData;

  tempScores <- 
    pathwayWeightsBildU133A[[i1]][genesInXLS] %*% 
      pathwayDataXLSBildBatch[[i1]]

  pathwayScoresXLSBildBatch[[i1]] <- tempScores[1,]

}



###################################################
### chunk number 25: plotOursVsBild1
###################################################

par(mfrow=c(2,2))

plot(pathwayScoresCEL$Src, pathwayScoresCELBild$Src,
     xlab="Src CEL Scores",
     ylab="Src CEL Bild Scores", 
     main="CEL") 

plot(pathwayScoresXLS$Src, pathwayScoresXLSBild$Src,
     xlab="Src XLS Scores",
     ylab="Src XLS Bild Scores", 
     main="XLS") 

plot(pathwayScoresCELBatch$Src, pathwayScoresCELBildBatch$Src,
     xlab="Src CEL Batch Scores",
     ylab="Src CEL Bild Batch Scores", 
     main="CEL Batch") 

plot(pathwayScoresXLSBatch$Src, pathwayScoresXLSBildBatch$Src,
     xlab="Src XLS Batch Scores",
     ylab="Src XLS Bild Batch Scores", 
     main="XLS Batch") 

par(mfrow=c(1,1))



###################################################
### chunk number 26: plotOursVsBild2
###################################################

par(mfrow=c(2,2))

plot(celRunDate, pathwayScoresCEL$Src - pathwayScoresCELBild$Src,
     xlab="Run Date",
     ylab="Src CEL - CEL Bild", 
     main="CEL by Date") 

plot(celRunDate, pathwayScoresXLS$Src - pathwayScoresXLSBild$Src,
     xlab="Run Date",
     ylab="Src XLS - XLS Bild", 
     main="XLS by Date") 

plot(celRunDate, pathwayScoresCELBatch$Src - pathwayScoresCELBildBatch$Src,
     xlab="RunDate",
     ylab="Src CEL Batch - CEL Bild Batch", 
     main="CEL Batch by Date") 

plot(celRunDate, pathwayScoresXLSBatch$Src - pathwayScoresXLSBildBatch$Src,
     xlab="Run Date",
     ylab="Src XLS Batch - XLS Bild Batch", 
     main="XLS Batch by Date") 

par(mfrow=c(1,1))



###################################################
### chunk number 27: plotCELVsXLS1
###################################################

par(mfrow=c(2,2))

plot(pathwayScoresCEL$Src, pathwayScoresXLS$Src,
     xlab="Src CEL Scores",
     ylab="Src XLS Scores", 
     main="CEL") 

plot(pathwayScoresCELBild$Src, pathwayScoresXLSBild$Src,
     xlab="Src CEL Bild Scores",
     ylab="Src XLS Bild Scores", 
     main="Bild") 

plot(pathwayScoresCELBatch$Src, pathwayScoresXLSBatch$Src,
     xlab="Src CEL Batch Scores",
     ylab="Src XLS Batch Scores", 
     main="CEL Batch") 

plot(pathwayScoresCELBildBatch$Src, pathwayScoresXLSBildBatch$Src,
     xlab="Src CEL Bild Batch Scores",
     ylab="Src XLS Bild Batch Scores", 
     main="CEL Bild Batch") 

par(mfrow=c(1,1))



###################################################
### chunk number 28: plotCELVsXLS2
###################################################

par(mfrow=c(2,2))

plot(celRunDate, pathwayScoresCEL$Src - pathwayScoresXLS$Src,
     xlab="Run Date",
     ylab="Src CEL - XLS", 
     main="CEL") 

plot(celRunDate, pathwayScoresCELBild$Src - pathwayScoresXLSBild$Src,
     xlab="Run Date",
     ylab="Src CEL Bild - XLS Bild", 
     main="CEL Bild") 

plot(celRunDate, pathwayScoresCELBatch$Src - pathwayScoresXLSBatch$Src,
     xlab="Run Date",
     ylab="Src CEL Batch - XLS Batch", 
     main="CEL Batch") 

plot(celRunDate, pathwayScoresCELBildBatch$Src - pathwayScoresXLSBildBatch$Src,
     xlab="Run Date",
     ylab="Src CEL Bild Batch - XLS Bild Batch", 
     main="CEL Bild Batch") 

par(mfrow=c(1,1))



###################################################
### chunk number 29: plotNoBatchVsBatch1
###################################################

par(mfrow=c(2,2))

plot(pathwayScoresCEL$Src, pathwayScoresCELBatch$Src,
     xlab="Src CEL Scores",
     ylab="Src CEL Batch Scores", 
     main="CEL") 

plot(pathwayScoresCELBild$Src, pathwayScoresCELBildBatch$Src,
     xlab="Src CEL Bild Scores",
     ylab="Src CEL Bild Batch Scores", 
     main="Bild") 

plot(pathwayScoresXLS$Src, pathwayScoresXLSBatch$Src,
     xlab="Src XLS Scores",
     ylab="Src XLS Batch Scores", 
     main="XLS") 

plot(pathwayScoresXLSBild$Src, pathwayScoresXLSBildBatch$Src,
     xlab="Src XLS Bild Scores",
     ylab="Src XLS Bild Batch Scores", 
     main="XLS Bild") 

par(mfrow=c(1,1))



###################################################
### chunk number 30: plotNoBatchVsBatch2
###################################################

par(mfrow=c(2,2))

plot(celRunDate, pathwayScoresCEL$Src - pathwayScoresCELBatch$Src,
     xlab="Run Date",
     ylab="Src CEL - CEL Batch", 
     main="CEL") 

plot(celRunDate, pathwayScoresCELBild$Src - pathwayScoresCELBildBatch$Src,
     xlab="Run Date",
     ylab="Src CEL Bild - CEL Bild Batch Scores", 
     main="CEL Bild") 

plot(celRunDate, pathwayScoresXLS$Src - pathwayScoresXLSBatch$Src,
     xlab="Run Date",
     ylab="Src XLS - XLS Batch Scores", 
     main="XLS") 

plot(celRunDate, pathwayScoresXLSBild$Src - pathwayScoresXLSBildBatch$Src,
     xlab="Run Date",
     ylab="Src XLS Bild - XLS Bild Batch Scores", 
     main="XLS Bild") 

par(mfrow=c(1,1))



###################################################
### chunk number 31: saveStuff
###################################################

save(pathwayCELDir, pathwayCELs, pathwayShortNames, pathways,
     file=paste("RDataObjects","pathwayNames.Rda",
       sep=.Platform$file.sep));

save(pathwayRMA, file=paste("RDataObjects","pathwayRMA.Rda",
       sep=.Platform$file.sep));

save(pathwayGenes,            pathwayGenesBild,
     pathwayGenesU133A,       pathwayGenesBildU133A,
     file=paste("RDataObjects","pathwayGenes.Rda",
       sep=.Platform$file.sep));


save(pathwayWeightsU133A,     pathwayWeightsBildU133A,
     file=paste("RDataObjects","pathwayWeights.Rda",
       sep=.Platform$file.sep));

save(pathwayDataU133A,        pathwayDataBildU133A,
     pathwayDataCEL,          pathwayDataXLS,
     pathwayDataCELBild,      pathwayDataXLSBild,
     pathwayDataCELBatch,     pathwayDataXLSBatch,
     pathwayDataCELBildBatch, pathwayDataXLSBildBatch,
     file=paste("RDataObjects","pathwayData.Rda",
       sep=.Platform$file.sep));

save(pathwayCellScoresU133A,    pathwayCellScoresBildU133A,
     pathwayScoresCEL,          pathwayScoresXLS,
     pathwayScoresCELBild,      pathwayScoresXLSBild,
     pathwayScoresCELBatch,     pathwayScoresXLSBatch,
     pathwayScoresCELBildBatch, pathwayScoresXLSBildBatch,
     file=paste("RDataObjects","pathwayScores.Rda",
       sep=.Platform$file.sep));



###################################################
### chunk number 32: sessionInfo
###################################################

sessionInfo();



