###################################################
### chunk number 1: options
###################################################

options(width=80);



###################################################
### chunk number 2: getLibraries
###################################################

library(survival)



###################################################
### chunk number 3: loadRawData
###################################################

load(file.path("RDataObjects","clinicalInfo.Rda"))
load(file.path("RDataObjects","pathwayScores.Rda"))



###################################################
### chunk number 4: buildSurvs
###################################################

survDressman <- with(clinicalInfo, Surv(SurvMonths, Censoring=="Dead"))
survBild <- with(clinicalInfo, Surv(SurvMonths, CensoringBild=="Dead"))
rownames(survDressman) <- rownames(clinicalInfo);
rownames(survBild) <- rownames(clinicalInfo);



###################################################
### chunk number 5: buildPathSurvFns
###################################################

pathTest <- function(surv, clin, score, resp="All"){
  ## pathTest -- tests for difference in survival associated with
  ##   high/low values of score. Attention can be restricted
  ##   to a subset of the patients based on their response
  ##   status, resp. Allowed values for resp are "All" (default), 
  ##   "CR", and "NR".
  if(resp=="All"){
    ourTest <- survdiff(surv ~ (score > median(score)),
                        data=cbind(clin, score[rownames(clin)]));
  }else{
    ourTest <- survdiff(surv[Response==resp] ~
                        (score[Response==resp] > median(score)),
                        data=cbind(clin, score[rownames(clin)]));
  }
  return(ourTest);
}

pathKM <- function(surv, clin, score, resp="All"){
  ## pathKM -- fits survival survival curves associated with
  ##   high/low values of score. Attention can be restricted
  ##   to a subset of the patients based on their response
  ##   status, resp. Allowed values for resp are "All" (default), 
  ##   "CR", and "NR".
  if(resp=="All"){
    ourTest <- survfit(surv ~ (score > median(score)),
                       data=cbind(clin, score[rownames(clin)]));
  }else{
    ourTest <- survfit(surv[Response==resp] ~
                       (score[Response==resp] > median(score)),
                       data=cbind(clin, score[rownames(clin)]));
  }
  return(ourTest);
}





###################################################
### chunk number 6: runDiffTests
###################################################

pathways <- names(pathwayScoresCEL)
pathways

pathwayScores <- 
  c("pathwayScoresCEL",      "pathwayScoresCELBild",
    "pathwayScoresCELBatch", "pathwayScoresCELBildBatch",
    "pathwayScoresXLS",      "pathwayScoresXLSBild",
    "pathwayScoresXLSBatch", "pathwayScoresXLSBildBatch")

patientSubgroups <- c("NR", "CR", "All")

pathwaySurvTests <- vector("list", length(pathways));
names(pathwaySurvTests) <- pathways

for(pathway in pathways){

  pathwaySurvTests[[pathway]] <- 
    vector("list", length(pathwayScores))
  names(pathwaySurvTests[[pathway]]) <- pathwayScores

  for(pathwayScore in pathwayScores){
    pathwaySurvTests[[pathway]][[pathwayScore]] <-
      vector("list", length(patientSubgroups))
    names(pathwaySurvTests[[pathway]][[pathwayScore]]) <-
      patientSubgroups
  }
}

pathwayKMFits <- pathwaySurvTests
pathwaySurvTestsBild <- pathwaySurvTests
pathwayKMFitsBild <- pathwaySurvTests

for(pathway in pathways){
  for(pathwayScore in pathwayScores){
    for(patientSubgroup in patientSubgroups){

      pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]] <-
        pathTest(survDressman, clinicalInfo, 
                 get(pathwayScore)[[pathway]],
                 patientSubgroup)
 
     pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]] <-
        pathKM(survDressman, clinicalInfo, 
               get(pathwayScore)[[pathway]],
               patientSubgroup)

      pathwaySurvTestsBild[[pathway]][[pathwayScore]][[patientSubgroup]] <-
        pathTest(survBild, clinicalInfo, 
                 get(pathwayScore)[[pathway]],
                 patientSubgroup)
 
     pathwayKMFitsBild[[pathway]][[pathwayScore]][[patientSubgroup]] <-
        pathKM(survBild, clinicalInfo, 
               get(pathwayScore)[[pathway]],
               patientSubgroup)

    }
  }
}



###################################################
### chunk number 7: getPValues
###################################################

pathwaySurvPVals <- vector("list", length(pathways))
names(pathwaySurvPVals) <- pathways
pathwaySurvBildPVals <- pathwaySurvPVals

for(pathway in pathways){
  
  temp <- matrix(0, length(pathwayScores), length(patientSubgroups))
  rownames(temp) <- pathwayScores
  colnames(temp) <- patientSubgroups

  tempBild <- temp

  for(pathwayScore in pathwayScores){
    for(patientSubgroup in patientSubgroups){
      temp[pathwayScore, patientSubgroup] <- 
        1 - pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1)
      tempBild[pathwayScore, patientSubgroup] <- 
        1 - pchisq(pathwaySurvTestsBild[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1)
    }
  }

  pathwaySurvPVals[[pathway]] <- temp;
  pathwaySurvBildPVals[[pathway]] <- tempBild;

}



###################################################
### chunk number 8: checkArgOrder
###################################################

names(pathwayKMFits$Src$pathwayScoresCEL$NR)
pathwayKMFits$Src$pathwayScoresCEL$NR$strata.all



###################################################
### chunk number 9: plotKMQuartet eval=FALSE
###################################################
## 
## par(mfrow=c(2,2))
## 
## for(pathwayScore in scoreList[1:4]){
##   
##   plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
##        col=c("blue","red"), lty=1, lwd=1, 
##        xlab="Surv in Months",
##        ylab="Propn Alive",
##        main=paste(pathway, pathwayScore, patientSubgroup))
##   legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
##          legend=c(paste(c("Low", "High"), pathway)),
##          col=c("blue","red"), lty=1, cex=0.75)
##   text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
##        paste("p =", 
##              format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
##        cex=0.75, adj=c(0,0))
##   
## }
## 
## par(mfrow=c(1,1))
## 


###################################################
### chunk number 10: tabulateSrcPValues
###################################################

pathway <- "Src"
pathwaySurvPVals[[pathway]]
pathwaySurvBildPVals[[pathway]]



###################################################
### chunk number 11: plotKMSrcCELNR
###################################################

scoreList <- pathwayScores[1:4]
patientSubgroup <- "NR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 12: plotKMSrcCELCR
###################################################

patientSubgroup <- "CR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 13: plotKMSrcCELAll
###################################################

patientSubgroup <- "All"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 14: plotKMSrcXLSNR
###################################################

scoreList <- pathwayScores[5:8]
patientSubgroup <- "NR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 15: plotKMSrcXLSCR
###################################################

patientSubgroup <- "CR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 16: plotKMSrcXLSAll
###################################################

patientSubgroup <- "All"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 17: tabulateE2F3PValues
###################################################

pathway <- "E2F3"
pathwaySurvPVals[[pathway]]
pathwaySurvBildPVals[[pathway]]



###################################################
### chunk number 18: plotKME2F3CELNR
###################################################

scoreList <- pathwayScores[1:4]
patientSubgroup <- "NR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 19: plotKME2F3CELCR
###################################################

patientSubgroup <- "CR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 20: plotKME2F3CELAll
###################################################

patientSubgroup <- "All"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 21: plotKME2F3XLSNR
###################################################

scoreList <- pathwayScores[5:8]
patientSubgroup <- "NR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 22: plotKME2F3XLSCR
###################################################

patientSubgroup <- "CR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 23: plotKME2F3XLSAll
###################################################

patientSubgroup <- "All"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 24: tabulateMycPValues
###################################################

pathway <- "Myc"
pathwaySurvPVals[[pathway]]
pathwaySurvBildPVals[[pathway]]



###################################################
### chunk number 25: plotKMMycCELNR
###################################################

scoreList <- pathwayScores[1:4]
patientSubgroup <- "NR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 26: plotKMMycCELCR
###################################################

patientSubgroup <- "CR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 27: plotKMMycCELAll
###################################################

patientSubgroup <- "All"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 28: plotKMMycXLSNR
###################################################

scoreList <- pathwayScores[5:8]
patientSubgroup <- "NR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 29: plotKMMycXLSCR
###################################################

patientSubgroup <- "CR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 30: plotKMMycXLSAll
###################################################

patientSubgroup <- "All"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 31: tabulateRasPValues
###################################################

pathway <- "Ras"
pathwaySurvPVals[[pathway]]
pathwaySurvBildPVals[[pathway]]



###################################################
### chunk number 32: plotKMRasCELNR
###################################################

scoreList <- pathwayScores[1:4]
patientSubgroup <- "NR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 33: plotKMRasCELCR
###################################################

patientSubgroup <- "CR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 34: plotKMRasCELAll
###################################################

patientSubgroup <- "All"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 35: plotKMRasXLSNR
###################################################

scoreList <- pathwayScores[5:8]
patientSubgroup <- "NR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 36: plotKMRasXLSCR
###################################################

patientSubgroup <- "CR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 37: plotKMRasXLSAll
###################################################

patientSubgroup <- "All"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 38: tabulateBcatPValues
###################################################

pathway <- "Bcat"
pathwaySurvPVals[[pathway]]
pathwaySurvBildPVals[[pathway]]



###################################################
### chunk number 39: plotKMBcatCELNR
###################################################

scoreList <- pathwayScores[1:4]
patientSubgroup <- "NR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 40: plotKMBcatCELCR
###################################################

patientSubgroup <- "CR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 41: plotKMBcatCELAll
###################################################

patientSubgroup <- "All"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 42: plotKMBcatXLSNR
###################################################

scoreList <- pathwayScores[5:8]
patientSubgroup <- "NR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 43: plotKMBcatXLSCR
###################################################

patientSubgroup <- "CR"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 44: plotKMBcatXLSAll
###################################################

patientSubgroup <- "All"

par(mfrow=c(2,2))

for(pathwayScore in scoreList[1:4]){
  
  plot(pathwayKMFits[[pathway]][[pathwayScore]][[patientSubgroup]],
       col=c("blue","red"), lty=1, lwd=1, 
       xlab="Surv in Months",
       ylab="Propn Alive",
       main=paste(pathway, pathwayScore, patientSubgroup))
  legend(x=0.6*par()$usr[2], y=0.95*par()$usr[4],
         legend=c(paste(c("Low", "High"), pathway)),
         col=c("blue","red"), lty=1, cex=0.75)
  text(x=0.05*par()$usr[2], y=0.05*par()$usr[4],
       paste("p =", 
             format(1-pchisq(pathwaySurvTests[[pathway]][[pathwayScore]][[patientSubgroup]]$chisq,1), digits=4)),
       cex=0.75, adj=c(0,0))
  
}

par(mfrow=c(1,1))




###################################################
### chunk number 45: srcHighLow
###################################################

sort(survDressman[clinicalInfo$Response=="NR"])

srcHighLowNR <- 
  c("H", "L", "L", "H", "H",
    "H", "H", "H", "H", "H",
    "L", "H", "H", "H", "H", # alt HLHHH
    "H", "H", "L", "L", "H",
    "L", "H", "L", "L", "L", 
    "L", "L", "L", "L", "L",
    "L", "H", "H", "L");

names(srcHighLowNR) <- 
  rownames(sort(survDressman[clinicalInfo$Response=="NR"]))

srcHighLowNR



###################################################
### chunk number 46: plotSRCHighLowNRCEL
###################################################

temp <- pathwayScoresCEL$Src[names(srcHighLowNR)]
dotchart(temp, groups=as.factor(srcHighLowNR),
         main="Src NRs: Scores vs Calls",xlab="Src: CEL")



###################################################
### chunk number 47: plotSRCHighLowNRCELBild
###################################################

temp <- pathwayScoresCELBild$Src[names(srcHighLowNR)]
dotchart(temp, groups=as.factor(srcHighLowNR),
         main="Src NRs: Scores vs Calls",xlab="Src: CEL Bild")



###################################################
### chunk number 48: plotSRCHighLowNRCELBatch
###################################################

temp <- pathwayScoresCELBatch$Src[names(srcHighLowNR)]
dotchart(temp, groups=as.factor(srcHighLowNR),
         main="Src NRs: Scores vs Calls",xlab="Src: CEL Batch")



###################################################
### chunk number 49: plotSRCHighLowNRCELBildBatch
###################################################

temp <- pathwayScoresCELBildBatch$Src[names(srcHighLowNR)]
dotchart(temp, groups=as.factor(srcHighLowNR),
         main="Src NRs: Scores vs Calls",xlab="Src: CEL Bild Batch")



###################################################
### chunk number 50: plotSRCHighLowNRXLS
###################################################

temp <- pathwayScoresXLS$Src[names(srcHighLowNR)]
dotchart(temp, groups=as.factor(srcHighLowNR),
         main="Src NRs: Scores vs Calls",xlab="Src: XLS")



###################################################
### chunk number 51: plotSRCHighLowNRXLSBild
###################################################

temp <- pathwayScoresXLSBild$Src[names(srcHighLowNR)]
dotchart(temp, groups=as.factor(srcHighLowNR),
         main="Src NRs: Scores vs Calls",xlab="Src: XLS Bild")



###################################################
### chunk number 52: plotSRCHighLowNRXLSBatch
###################################################

temp <- pathwayScoresXLSBatch$Src[names(srcHighLowNR)]
dotchart(temp, groups=as.factor(srcHighLowNR),
         main="Src NRs: Scores vs Calls",xlab="Src: XLS Batch")



###################################################
### chunk number 53: plotSRCHighLowNRXLSBildBatch
###################################################

temp <- pathwayScoresXLSBildBatch$Src[names(srcHighLowNR)]
dotchart(temp, groups=as.factor(srcHighLowNR),
         main="Src NRs: Scores vs Calls",xlab="Src: XLS Bild Batch")



###################################################
### chunk number 54: e2f3HighLow
###################################################

sort(survDressman[clinicalInfo$Response=="NR"])

e2f3HighLowNR <- 
  c("L", "H", "L", "L", "L",
    "L", "H", "L", "L", "L",
    "L", "L", "L", "H", "H", # alt LHHLH
    "L", "L", "L", "H", "H",
    "H", "L", "L", "L", "H", 
    "L", "H", "L", "H", "H",
    "H", "H", "H", "H");

names(e2f3HighLowNR) <- 
  rownames(sort(survDressman[clinicalInfo$Response=="NR"]))

e2f3HighLowNR



###################################################
### chunk number 55: plotE2F3HighLowNRCEL
###################################################

temp <- pathwayScoresCEL$E2F3[names(e2f3HighLowNR)]
dotchart(temp, groups=as.factor(e2f3HighLowNR),
         main="E2F3 NRs: Scores vs Calls",xlab="E2F3: CEL")



###################################################
### chunk number 56: plotE2F3HighLowNRCELBild
###################################################

temp <- pathwayScoresCELBild$E2F3[names(e2f3HighLowNR)]
dotchart(temp, groups=as.factor(e2f3HighLowNR),
         main="E2F3 NRs: Scores vs Calls",xlab="E2F3: CEL Bild")



###################################################
### chunk number 57: plotE2F3HighLowNRCELBatch
###################################################

temp <- pathwayScoresCELBatch$E2F3[names(e2f3HighLowNR)]
dotchart(temp, groups=as.factor(e2f3HighLowNR),
         main="E2F3 NRs: Scores vs Calls",xlab="E2F3: CEL Batch")



###################################################
### chunk number 58: plotE2F3HighLowNRCELBildBatch
###################################################

temp <- pathwayScoresCELBildBatch$E2F3[names(e2f3HighLowNR)]
dotchart(temp, groups=as.factor(e2f3HighLowNR),
         main="E2F3 NRs: Scores vs Calls",xlab="E2F3: CEL Bild Batch")



###################################################
### chunk number 59: plotE2F3HighLowNRXLS
###################################################

temp <- pathwayScoresXLS$E2F3[names(e2f3HighLowNR)]
dotchart(temp, groups=as.factor(e2f3HighLowNR),
         main="E2F3 NRs: Scores vs Calls",xlab="E2F3: XLS")



###################################################
### chunk number 60: plotE2F3HighLowNRXLSBild
###################################################

temp <- pathwayScoresXLSBild$E2F3[names(e2f3HighLowNR)]
dotchart(temp, groups=as.factor(e2f3HighLowNR),
         main="E2F3 NRs: Scores vs Calls",xlab="E2F3: XLS Bild")



###################################################
### chunk number 61: plotE2F3HighLowNRXLSBatch
###################################################

temp <- pathwayScoresXLSBatch$E2F3[names(e2f3HighLowNR)]
dotchart(temp, groups=as.factor(e2f3HighLowNR),
         main="E2F3 NRs: Scores vs Calls",xlab="E2F3: XLS Batch")



###################################################
### chunk number 62: plotE2F3HighLowNRXLSBildBatch
###################################################

temp <- pathwayScoresXLSBildBatch$E2F3[names(e2f3HighLowNR)]
dotchart(temp, groups=as.factor(e2f3HighLowNR),
         main="E2F3 NRs: Scores vs Calls",xlab="E2F3: XLS Bild Batch")



###################################################
### chunk number 63: saveStuff
###################################################

save(survDressman, file=paste("RDataObjects", "survDressman.Rda",
                     sep=.Platform$file.sep))
save(survBild, file=paste("RDataObjects", "survBild.Rda",
                     sep=.Platform$file.sep))
save(pathwayScores, file=paste("RDataObjects", "pathwayScoreNames.Rda",
                     sep=.Platform$file.sep))
save(patientSubgroups, file=paste("RDataObjects", "patientSubgroups.Rda",
                     sep=.Platform$file.sep))
save(pathwaySurvTests, file=paste("RDataObjects", "pathwaySurvTests.Rda",
                     sep=.Platform$file.sep))
save(pathwayKMFits, file=paste("RDataObjects", "pathwayKMFits.Rda",
                     sep=.Platform$file.sep))
save(pathwaySurvTestsBild, 
     file=paste("RDataObjects", "pathwaySurvTestsBild.Rda",
                     sep=.Platform$file.sep))
save(pathwayKMFitsBild, 
     file=paste("RDataObjects", "pathwayKMFitsBild.Rda",
                     sep=.Platform$file.sep))



###################################################
### chunk number 64: sessionInfo
###################################################

sessionInfo();



